aboutsummaryrefslogtreecommitdiffstats
path: root/src/plugins/coreplugin/generatedfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugins/coreplugin/generatedfile.h')
-rw-r--r--src/plugins/coreplugin/generatedfile.h36
1 files changed, 20 insertions, 16 deletions
diff --git a/src/plugins/coreplugin/generatedfile.h b/src/plugins/coreplugin/generatedfile.h
index 807f2f5166..4caf2bf119 100644
--- a/src/plugins/coreplugin/generatedfile.h
+++ b/src/plugins/coreplugin/generatedfile.h
@@ -25,10 +25,12 @@
#pragma once
-#include "id.h"
+#include "core_global.h"
+
+#include <utils/id.h>
-#include <QSharedDataPointer>
#include <QList>
+#include <QSharedDataPointer>
namespace Core {
class GeneratedFilePrivate;
@@ -36,18 +38,20 @@ class GeneratedFilePrivate;
class CORE_EXPORT GeneratedFile
{
public:
- enum Attribute { // Open this file in editor
- OpenEditorAttribute = 0x01,
- // Open project
- OpenProjectAttribute = 0x02,
- /* File is generated by external scripts, do not write out,
- * see BaseFileWizard::writeFiles() */
- CustomGeneratorAttribute = 0x4,
- /* File exists and the user indicated that he wants to keep it */
- KeepExistingFileAttribute = 0x8,
- /* Force overwriting of a file without asking the user to keep it */
- ForceOverwrite = 0x10
- };
+ enum Attribute {
+ // Open this file in editor
+ OpenEditorAttribute = 0x01,
+ // Open project
+ OpenProjectAttribute = 0x02,
+ // File is generated by external scripts, do not write out, see BaseFileWizard::writeFiles()
+ CustomGeneratorAttribute = 0x4,
+ // File exists and the user indicated that he wants to keep it
+ KeepExistingFileAttribute = 0x8,
+ // Force overwriting of a file without asking the user to keep it
+ ForceOverwrite = 0x10,
+ // Mark the document temporary after opening the file
+ TemporaryFile = 0x20
+ };
Q_DECLARE_FLAGS(Attributes, Attribute)
GeneratedFile();
@@ -72,8 +76,8 @@ public:
void setBinary(bool b);
// Id of editor to open the file with
- Id editorId() const;
- void setEditorId(Id id);
+ Utils::Id editorId() const;
+ void setEditorId(Utils::Id id);
bool write(QString *errorMessage) const;